@@ -278,7 +278,7 @@ class ChatSparkLLM(BaseChatModel):
         async for content in self.client.a_subscribe(timeout=self.request_timeout):
             if "usage" in content:
                 final_frame = True
-                llm_output["token_usage.png"] = content["usage"]
+                llm_output["token_usage"] = content["usage"]
             if "data" not in content and not final_frame:
                 continue
             if not final_frame:
@@ -325,7 +325,7 @@ class ChatSparkLLM(BaseChatModel):
         for content in self.client.subscribe(timeout=self.request_timeout):
             if "usage" in content:
                 final_frame = True
-                llm_output["token_usage.png"] = content["usage"]
+                llm_output["token_usage"] = content["usage"]
             if "data" not in content and not final_frame:
                 continue
             if not final_frame:
@@ -372,7 +372,7 @@ class ChatSparkLLM(BaseChatModel):
         completion = {}
         for content in self.client.subscribe(timeout=self.request_timeout):
             if "usage" in content:
-                llm_output["token_usage.png"] = content["usage"]
+                llm_output["token_usage"] = content["usage"]
             if "data" not in content:
                 continue
             completion = content["data"]
